@@ -30,18 +30,18 @@ from __future__ import print_function
 # 7. For every halo in ball-query result, execute numpy's intersect1d on
 #    particle IDs
 # 8. Parentage is described by a fraction of particles that pass from one to
-#    the other; we have both descendent fractions and ancestory fractions. 
+#    the other; we have both descendent fractions and ancestor fractions. 
 
 
 import numpy as np
-import h5py
-import time
-import pdb
-from yt.extern.six.moves import cPickle
+from yt.utilities.on_demand_imports import _h5py as h5py
 import glob
+import os
 
-from yt.funcs import *
+from yt.extern.six.moves import cPickle
 from yt.extern.pykdtree import KDTree
+from yt.funcs import mylog, get_pbar
+
 import yt.extern.pydot as pydot
 
 # We don't currently use this, but we may again find a use for it in the
@@ -180,7 +180,7 @@ class HaloCatalog(object):
 
     def calculate_parentage_fractions(self, other_catalog, radius = 0.10):
         parentage_fractions = {}
-        if self.halo_positions == None or other_catalog.halo_positions == None:
+        if self.halo_positions is None or other_catalog.halo_positions is None:
             return parentage_fractions
         mylog.debug("Ball-tree query with radius %0.3e", radius)
         all_nearest = self.halo_kdtree.query_ball_tree(
@@ -226,9 +226,9 @@ class EnzoFOFMergerBranch(object):
         self.progenitor = -1
         max_relationship = 0.0
         halo_count = 0
-        sorted_keys = sorted(tree.relationships[output_num][halo_id].keys())
-        for k in sorted_keys:
-            if not str(k).isdigit(): continue
+        keys = list(tree.relationships[output_num][halo_id].keys())
+        keys.remove('NumberOfParticles')
+        for k in sorted(keys):
             v = tree.relationships[output_num][halo_id][k]
             if v[1] > min_relation and halo_count < max_children:
                 halo_count += 1
@@ -320,7 +320,7 @@ class EnzoFOFMergerTree(object):
         for redshift in self.redshifts.values():
             if redshift <= zrange[0] and redshift >= zrange[1]:
                 # some reverse lookup magic--assumes unique cycle/z pairs
-                cycle = [key for key,value in mt.redshifts.items() \
+                cycle = [key for key,value in self.redshifts.items() \
                          if value == redshift][0]
                 del self.redshifts[cycle]
 
@@ -490,7 +490,7 @@ class EnzoFOFMergerTree(object):
         It stores info from the FOF_groups file: location, mass, id, etc.
         """
         f = h5py.File("%s/%s" % (self.FOF_directory, filename), 'a')
-        cycle_fin = self.redshifts.keys()[-1]
+        cycle_fin = sorted(list(self.redshifts.keys()))[-1]
         halo_id = self.levels[cycle_fin][0].halo_id
         halo = "halo%05d" % halo_id
         if halo in f:
@@ -568,7 +568,7 @@ class EnzoFOFMergerTree(object):
             automatically. See GraphViz (e.g. "dot -v")
             for a list of available output formats.
         """
-        if filename == None: 
+        if filename is None:
             filename = "%s/tree_halo%5.5d.gv" % \
                         (self.FOF_directory, self.halonum)
         # Create the pydot graph object.
@@ -598,7 +598,6 @@ class EnzoFOFMergerTree(object):
                     #      (lvl, br.halo_id, next_lvl, c[0], color)
                     
                     #fp.write(line)
-                    last_level = (ii,lvl)
         for ii,lvl in enumerate(sorted_lvl):
             npart_max = 0
             for br in self.levels[lvl]:
@@ -714,8 +713,8 @@ def plot_halo_evolution(filename, halo_id, x_quantity='cycle', y_quantity='mass'
         The filename to which you saved the hdf5 data from save_halo_evolution
     halo_id : int
         The halo in 'filename' that you want to follow
-    x_quantity, y_quantity : str, optional
-        The quantity that you want to plot as the x_coord (or y_coords).
+    x_quantity : str, optional
+        The quantity that you want to plot as the x_coord.
         Valid options are:
 
            * cycle
@@ -733,8 +732,12 @@ def plot_halo_evolution(filename, halo_id, x_quantity='cycle', y_quantity='mass'
            * COM_vy
            * COM_vz
 
-    x_log, y_log : bool, optional
-        Do you want the x(y)-axis to be in log or linear?
+    y_quantity : str, optional
+        The quantity that you want to plot as the y_coord.
+    x_log : bool, optional
+        Do you want the x-axis to be in log or linear?
+    y_log : bool, optional
+        Do you want the y-axis to be in log or linear?
     FOF_directory : str, optional
         Directory where FOF files (and hdf file) are located
 
