@@ -24,7 +24,8 @@ http://adsabs.harvard.edu/abs/2013MNRAS.428.1395B
 
 from yt.extern.six import string_types
 import numpy as np
-from yt.funcs import *
+from yt.funcs import mylog, get_pbar
+from yt.units.yt_array import YTArray
 from yt.utilities.physical_constants import mp
 from yt.utilities.parallel_tools.parallel_analysis_interface import \
      parallel_objects
@@ -51,14 +52,13 @@ class PhotonModel(object):
 
 class ThermalPhotonModel(PhotonModel):
     r"""
-    Initialize a ThermalPhotonModel from a thermal spectrum. 
+    Initialize a ThermalPhotonModel from a thermal spectrum.
 
     Parameters
     ----------
-
     spectral_model : `SpectralModel`
         A thermal spectral model instance, either of `XSpecThermalModel`
-        or `TableApecModel`. 
+        or `TableApecModel`.
     X_H : float, optional
         The hydrogen mass fraction.
     Zmet : float or string, optional
@@ -72,14 +72,20 @@ class ThermalPhotonModel(PhotonModel):
         "invert_cdf": Invert the cumulative distribution function of the spectrum.
         "accept_reject": Acceptance-rejection method using the spectrum. 
         The first method should be sufficient for most cases. 
+    prng : NumPy `RandomState` object or numpy.random                                                                            
+        A pseudo-random number generator. Typically will only be specified                                                            
+        if you have a reason to generate the same set of random numbers, such as for a 
+        test. Default is the numpy.random module.                                                                      
     """
     def __init__(self, spectral_model, X_H=0.75, Zmet=0.3, 
-                 photons_per_chunk=10000000, method="invert_cdf"):
+                 photons_per_chunk=10000000, method="invert_cdf",
+                 prng=np.random):
         self.X_H = X_H
         self.Zmet = Zmet
         self.spectral_model = spectral_model
         self.photons_per_chunk = photons_per_chunk
         self.method = method
+        self.prng = prng
 
     def __call__(self, data_source, parameters):
 
@@ -127,7 +133,7 @@ class ThermalPhotonModel(PhotonModel):
             if num_cells == 0:
                 continue
             vol = chunk["cell_volume"].in_cgs().v
-            EM = (chunk["density"]/mp).v**2
+            EM = (chunk["density"]/mp).in_cgs().v**2
             EM *= 0.5*(1.+self.X_H)*self.X_H*vol
 
             if isinstance(self.Zmet, string_types):
@@ -173,7 +179,7 @@ class ThermalPhotonModel(PhotonModel):
                 tot_ph_c = cspec.d.sum()
                 tot_ph_m = mspec.d.sum()
 
-                u = np.random.random(size=n_current)
+                u = self.prng.uniform(size=n_current)
 
                 cell_norm_c = tot_ph_c*cem
                 cell_norm_m = tot_ph_m*metalZ[ibegin:iend]*cem
@@ -200,7 +206,7 @@ class ThermalPhotonModel(PhotonModel):
                     if cn == 0: continue
                     # The rather verbose form of the few next statements is a
                     # result of code optimization and shouldn't be changed
-                    # without checking for perfomance degradation. See
+                    # without checking for performance degradation. See
                     # https://bitbucket.org/yt_analysis/yt/pull-requests/1766
                     # for details.
                     if self.method == "invert_cdf":
@@ -208,7 +214,7 @@ class ThermalPhotonModel(PhotonModel):
                         cumspec += Z * cumspec_m
                         norm_factor = 1.0 / cumspec[-1]
                         cumspec *= norm_factor
-                        randvec = np.random.uniform(size=cn)
+                        randvec = self.prng.uniform(size=cn)
                         randvec.sort()
                         cell_e = np.interp(randvec, cumspec, ebins)
                     elif self.method == "accept_reject":
@@ -216,9 +222,9 @@ class ThermalPhotonModel(PhotonModel):
                         tot_spec += Z * mspec.d
                         norm_factor = 1.0 / tot_spec.sum()
                         tot_spec *= norm_factor
-                        eidxs = np.random.choice(nchan, size=cn, p=tot_spec)
+                        eidxs = self.prng.choice(nchan, size=cn, p=tot_spec)
                         cell_e = emid[eidxs]
-                    energies[ei:ei+cn] = cell_e
+                    energies[int(ei):int(ei + cn)] = cell_e
                     cell_counter += 1
                     pbar.update(cell_counter)
                     ei += cn
@@ -251,4 +257,6 @@ class ThermalPhotonModel(PhotonModel):
         mylog.info("Number of photons generated: %d" % int(np.sum(photons["NumberOfPhotons"])))
         mylog.info("Number of cells with photons: %d" % len(photons["x"]))
 
+        self.spectral_model.cleanup_spectrum()
+
         return photons
