@@ -22,16 +22,7 @@ from .octree_subset import \
 from .static_output import \
     Dataset
 
-from .particle_io import \
-    ParticleIOHandler, \
-    particle_handler_registry
-
 from .profiles import \
-    YTEmptyProfileData, \
-    BinnedProfile, \
-    BinnedProfile1D, \
-    BinnedProfile2D, \
-    BinnedProfile3D, \
     create_profile, \
     Profile1D, \
     Profile2D, \
