@@ -23,7 +23,6 @@ import shelve
 from collections import defaultdict
 from contextlib import contextmanager
 
-from yt.data_objects.particle_io import particle_handler_registry
 from yt.fields.derived_field import \
     DerivedField
 from yt.frontends.ytdata.utilities import \
@@ -33,7 +32,7 @@ from yt.funcs import \
     mylog, \
     ensure_list, \
     fix_axis, \
-    iterable
+    iterable, validate_width_tuple
 from yt.units.unit_object import UnitParseError
 from yt.units.yt_array import \
     YTArray, \
@@ -51,7 +50,7 @@ from yt.utilities.exceptions import \
     YTDataSelectorNotImplemented, \
     YTDimensionalityError, \
     YTBooleanObjectError, \
-    YTBooleanObjectsWrongDataset
+    YTBooleanObjectsWrongDataset, YTException
 from yt.utilities.lib.marching_cubes import \
     march_cubes_grid, march_cubes_grid_flux
 from yt.utilities.parallel_tools.parallel_analysis_interface import \
@@ -72,29 +71,6 @@ from yt.data_objects.profiles import create_profile
 
 data_object_registry = {}
 
-def force_array(item, shape):
-    try:
-        return item.copy()
-    except AttributeError:
-        if item:
-            return np.ones(shape, dtype='bool')
-        else:
-            return np.zeros(shape, dtype='bool')
-
-def restore_field_information_state(func):
-    """
-    A decorator that takes a function with the API of (self, grid, field)
-    and ensures that after the function is called, the field_parameters will
-    be returned to normal.
-    """
-    def save_state(self, grid, field=None, *args, **kwargs):
-        old_params = grid.field_parameters
-        grid.field_parameters = self.field_parameters
-        tr = func(self, grid, field, *args, **kwargs)
-        grid.field_parameters = old_params
-        return tr
-    return save_state
-
 def sanitize_weight_field(ds, field, weight):
     field_object = ds._get_field_info(field)
     if weight is None:
@@ -153,6 +129,7 @@ class YTDataContainer(object):
         self._default_field_parameters = {
             'center': self.ds.arr(np.zeros(3, dtype='float64'), 'cm'),
             'bulk_velocity': self.ds.arr(np.zeros(3, dtype='float64'), 'cm/s'),
+            'bulk_magnetic_field': self.ds.arr(np.zeros(3, dtype='float64'), 'G'),
             'normal': self.ds.arr([0.0, 0.0, 1.0], ''),
         }
         if field_parameters is None: field_parameters = {}
@@ -215,6 +192,10 @@ class YTDataContainer(object):
                 self.center = self.ds.find_max(("gas", "density"))[1]
             elif center.startswith("max_"):
                 self.center = self.ds.find_max(center[4:])[1]
+            elif center.lower() == "min":
+                self.center = self.ds.find_min(("gas", "density"))[1]
+            elif center.startswith("min_"):
+                self.center = self.ds.find_min(center[4:])[1]
         else:
             self.center = self.ds.arr(center, 'code_length', dtype='float64')
         self.set_field_parameter('center', self.center)
@@ -242,13 +223,6 @@ class YTDataContainer(object):
         """
         return name in self.field_parameters
 
-    def convert(self, datatype):
-        """
-        This will attempt to convert a given unit to cgs from code units.
-        It either returns the multiplicative factor or throws a KeyError.
-        """
-        return self.ds[datatype]
-
     def clear_data(self):
         """
         Clears out all data from the YTDataContainer instance, freeing memory.
@@ -427,20 +401,72 @@ class YTDataContainer(object):
 
     _key_fields = None
     def write_out(self, filename, fields=None, format="%0.16e"):
-        if fields is None: fields=sorted(self.field_data.keys())
-        if self._key_fields is None: raise ValueError
-        field_order = self._key_fields[:]
-        for field in field_order: self[field]
-        field_order += [field for field in fields if field not in field_order]
-        fid = open(filename,"w")
-        fid.write("\t".join(["#"] + field_order + ["\n"]))
-        field_data = np.array([self.field_data[field] for field in field_order])
-        for line in range(field_data.shape[1]):
-            field_data[:,line].tofile(fid, sep="\t", format=format)
-            fid.write("\n")
-        fid.close()
+        """Write out the YTDataContainer object in a text file.
 
-    def save_object(self, name, filename = None):
+        This function will take a data object and produce a tab delimited text
+        file containing the fields presently existing and the fields given in
+        the ``fields`` list.
+
+        Parameters
+        ----------
+        filename : String
+            The name of the file to write to.
+
+        fields : List of string, Default = None
+            If this is supplied, these fields will be added to the list of
+            fields to be saved to disk. If not supplied, whatever fields
+            presently exist will be used.
+
+        format : String, Default = "%0.16e"
+            Format of numbers to be written in the file.
+
+        Raises
+        ------
+        ValueError
+            Raised when there is no existing field.
+
+        YTException
+            Raised when field_type of supplied fields is inconsistent with the
+            field_type of existing fields.
+
+        Examples
+        --------
+        >>> ds = fake_particle_ds()
+        >>> sp = ds.sphere(ds.domain_center, 0.25)
+        >>> sp.write_out("sphere_1.txt")
+        >>> sp.write_out("sphere_2.txt", fields=["cell_volume"])
+        """
+        if fields is None:
+            fields = sorted(self.field_data.keys())
+
+        if self._key_fields is None:
+            raise ValueError
+
+        field_order = self._key_fields
+        diff_fields = [field for field in fields if field not in field_order]
+        field_order += diff_fields
+        field_order = sorted(self._determine_fields(field_order))
+        field_types = {u for u, v in field_order}
+
+        if len(field_types) != 1:
+            diff_fields = self._determine_fields(diff_fields)
+            req_ftype = self._determine_fields(self._key_fields[0])[0][0]
+            f_type = {f for f in diff_fields if f[0] != req_ftype }
+            msg = ("Field type %s of the supplied field %s is inconsistent"
+                   " with field type '%s'." %
+                   ([f[0] for f in f_type], [f[1] for f in f_type], req_ftype))
+            raise YTException(msg)
+
+        for field in field_order: self[field]
+        with open(filename, "w") as fid:
+            field_header = [str(f) for f in field_order]
+            fid.write("\t".join(["#"] + field_header + ["\n"]))
+            field_data = np.array([self.field_data[field] for field in field_order])
+            for line in range(field_data.shape[1]):
+                field_data[:, line].tofile(fid, sep="\t", format=format)
+                fid.write("\n")
+
+    def save_object(self, name, filename=None):
         """
         Save an object.  If *filename* is supplied, it will be stored in
         a :mod:`shelve` file of that name.  Otherwise, it will be stored via
@@ -455,7 +481,7 @@ class YTDataContainer(object):
         else:
             self.index.save_object(self, name)
 
-    def to_dataframe(self, fields = None):
+    def to_dataframe(self, fields=None):
         r"""Export a data object to a pandas DataFrame.
 
         This function will take a data object and construct from it and
@@ -545,7 +571,7 @@ class YTDataContainer(object):
         else:
             data.update(self.field_data)
         # get the extra fields needed to reconstruct the container
-        tds_fields = tuple(self._determine_fields(list(self._tds_fields)))
+        tds_fields = tuple([('index', t) for t in self._tds_fields])
         for f in [f for f in self._container_fields + tds_fields \
                   if f not in data]:
             data[f] = self[f]
@@ -611,9 +637,16 @@ class YTDataContainer(object):
         the Glue environment, you can pass a *data_collection* object,
         otherwise Glue will be started.
         """
+        from yt.config import ytcfg
         from glue.core import DataCollection, Data
-        from glue.qt.glue_application import GlueApplication
-
+        if ytcfg.getboolean("yt", "__withintesting"):
+            from glue.core.application_base import \
+                Application as GlueApplication
+        else:
+            try:
+                from glue.app.qt.application import GlueApplication
+            except ImportError:
+                from glue.qt.glue_application import GlueApplication
         gdata = Data(label=label)
         for component_name in fields:
             gdata.add_component(self[component_name], component_name)
@@ -621,7 +654,12 @@ class YTDataContainer(object):
         if data_collection is None:
             dc = DataCollection([gdata])
             app = GlueApplication(dc)
-            app.start()
+            try:
+                app.start()
+            except AttributeError:
+                # In testing we're using a dummy glue application object
+                # that doesn't have a start method
+                pass
         else:
             data_collection.append(gdata)
 
@@ -1185,6 +1223,8 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface):
     _current_chunk = None
     _data_source = None
     _dimensionality = None
+    _max_level = None
+    _min_level = None
 
     def __init__(self, ds, field_parameters, data_source=None):
         ParallelAnalysisInterface.__init__(self)
@@ -1203,7 +1243,8 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface):
 
     @property
     def selector(self):
-        if self._selector is not None: return self._selector
+        if self._selector is not None:
+            return self._selector
         s_module = getattr(self, '_selector_module',
                            yt.geometry.selection_routines)
         sclass = getattr(s_module,
@@ -1258,7 +1299,7 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface):
             requested = self._determine_fields(list(set(fd.requested)))
             deps = [d for d in requested if d not in fields_to_get]
             fields_to_get += deps
-        return fields_to_get
+        return sorted(fields_to_get)
 
     def get_data(self, fields=None):
         if self._current_chunk is None:
@@ -1267,7 +1308,12 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface):
         nfields = []
         apply_fields = defaultdict(list)
         for field in self._determine_fields(fields):
-            if field[0] in self.ds.filtered_particle_types:
+            # We need to create the field on the raw particle types
+            # for particles types (when the field is not directly
+            # defined for the derived particle type only)
+            finfo = self.ds.field_info[field]
+
+            if field[0] in self.ds.filtered_particle_types and finfo._inherited_particle_filter:
                 f = self.ds.known_filters[field[0]]
                 apply_fields[field[0]].append(
                     (f.filtered_type, field[1]))
@@ -1436,10 +1482,42 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface):
         yield
         self._locked = False
 
+    @contextmanager
+    def _ds_hold(self, new_ds):
+        """
+        This contextmanager is used to take a data object and preserve its
+        attributes but allow the dataset that underlies it to be swapped out.
+        This is typically only used internally, and differences in unit systems
+        may present interesting possibilities.
+        """
+        old_ds = self.ds
+        old_index = self._index
+        self.ds = new_ds
+        self._index = new_ds.index
+        old_chunk_info = self._chunk_info
+        old_chunk = self._current_chunk
+        old_size = self.size
+        self._chunk_info = None
+        self._current_chunk = None
+        self.size = None
+        self._index._identify_base_chunk(self)
+        with self._chunked_read(None):
+            yield
+        self._index = old_index
+        self.ds = old_ds
+        self._chunk_info = old_chunk_info
+        self._current_chunk = old_chunk
+        self.size = old_size
+
     @contextmanager
     def _chunked_read(self, chunk):
         # There are several items that need to be swapped out
         # field_data, size, shape
+        obj_field_data = []
+        if hasattr(chunk, 'objs'):
+            for obj in chunk.objs:
+                obj_field_data.append(obj.field_data)
+                obj.field_data = YTFieldData()
         old_field_data, self.field_data = self.field_data, YTFieldData()
         old_chunk, self._current_chunk = self._current_chunk, chunk
         old_locked, self._locked = self._locked, False
@@ -1447,6 +1525,9 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface):
         self.field_data = old_field_data
         self._current_chunk = old_chunk
         self._locked = old_locked
+        if hasattr(chunk, 'objs'):
+            for obj in chunk.objs:
+                obj.field_data = obj_field_data.pop(0)
 
     @contextmanager
     def _activate_cache(self):
@@ -1497,6 +1578,46 @@ class YTSelectionContainer(YTDataContainer, ParallelAnalysisInterface):
             self.index._identify_base_chunk(self)
         return self._current_chunk.fcoords_vertex
 
+    @property
+    def max_level(self):
+        if self._max_level is None:
+            try:
+                return self.ds.max_level
+            except AttributeError:
+                return None
+        return self._max_level
+
+    @max_level.setter
+    def max_level(self, value):
+        if self._selector is not None:
+            del self._selector
+            self._selector = None
+        self._current_chunk = None
+        self.size = None
+        self.shape = None
+        self.field_data.clear()
+        self._max_level = value
+
+    @property
+    def min_level(self):
+        if self._min_level is None:
+            try:
+                return 0
+            except AttributeError:
+                return None
+        return self._min_level
+
+    @min_level.setter
+    def min_level(self, value):
+        if self._selector is not None:
+            del self._selector
+            self._selector = None
+        self.field_data.clear()
+        self.size = None
+        self.shape = None
+        self._current_chunk = None
+        self._min_level = value
+
 class YTSelectionContainer0D(YTSelectionContainer):
     _spatial = False
     _dimensionality = 0
@@ -1603,12 +1724,9 @@ class YTSelectionContainer2D(YTSelectionContainer):
                     "Currently we only support images centered at R=0. " +
                     "We plan to generalize this in the near future")
             from yt.visualization.fixed_resolution import CylindricalFixedResolutionBuffer
-            if iterable(width):
-                radius = max(width)
-            else:
-                radius = width
+            validate_width_tuple(width)
             if iterable(resolution): resolution = max(resolution)
-            frb = CylindricalFixedResolutionBuffer(self, radius, resolution)
+            frb = CylindricalFixedResolutionBuffer(self, width, resolution)
             return frb
 
         if center is None:
@@ -1770,7 +1888,7 @@ class YTSelectionContainer3D(YTSelectionContainer):
             else: f = open(filename, "w")
             for v1 in verts:
                 f.write("v %0.16e %0.16e %0.16e\n" % (v1[0], v1[1], v1[2]))
-            for i in range(len(verts)/3):
+            for i in range(len(verts)//3):
                 f.write("f %s %s %s\n" % (i*3+1, i*3+2, i*3+3))
             if not hasattr(filename, "write"): f.close()
         if sample_values is not None:
@@ -1901,8 +2019,8 @@ class YTSelectionContainer3D(YTSelectionContainer):
                 mv = max_val
             else:
                 mv = cons[level+1]
-            from yt.analysis_modules.level_sets.api import identify_contours
-            from yt.analysis_modules.level_sets.clump_handling import \
+            from yt.data_objects.level_sets.api import identify_contours
+            from yt.data_objects.level_sets.clump_handling import \
                 add_contour_field
             nj, cids = identify_contours(self, field, cons[level], mv)
             unique_contours = set([])
@@ -1920,29 +2038,6 @@ class YTSelectionContainer3D(YTSelectionContainer):
                     {'contour_slices_%s' % contour_key: cids})
         return cons, contours
 
-    def paint_grids(self, field, value, default_value=None):
-        """
-        This function paints every cell in our dataset with a given *value*.
-        If default_value is given, the other values for the given in every grid
-        are discarded and replaced with *default_value*.  Otherwise, the field is
-        mandated to 'know how to exist' in the grid.
-
-        Note that this only paints the cells *in the dataset*, so cells in grids
-        with child cells are left untouched.
-        """
-        for grid in self._grids:
-            if default_value is not None:
-                grid[field] = np.ones(grid.ActiveDimensions)*default_value
-            grid[field][self._get_point_indices(grid)] = value
-
-    _particle_handler = None
-
-    @property
-    def particles(self):
-        if self._particle_handler is None:
-            self._particle_handler = \
-                particle_handler_registry[self._type_name](self.ds, self)
-        return self._particle_handler
 
 
     def volume(self):
