@@ -21,14 +21,18 @@ from yt.frontends.ytdata.utilities import \
 from yt.funcs import \
     get_output_filename, \
     ensure_list, \
-    iterable
+    iterable, \
+    issue_deprecation_warning, \
+    mylog
 from yt.units.yt_array import \
     array_like_field, \
     YTQuantity
 from yt.units.unit_object import Unit
-from yt.data_objects.data_containers import YTFieldData
+from yt.data_objects.field_data import YTFieldData
 from yt.utilities.exceptions import \
-    YTIllDefinedProfile
+    YTIllDefinedProfile, \
+    YTIllDefinedBounds, \
+    YTProfileDataShape
 from yt.utilities.lib.misc_utilities import \
     new_bin_profile1d, \
     new_bin_profile2d, \
@@ -91,12 +95,22 @@ class ProfileND(ParallelAnalysisInterface):
         self.field_info = {}
         self.field_data = YTFieldData()
         if weight_field is not None:
-            self.variance = YTFieldData()
+            self.standard_deviation = YTFieldData()
             weight_field = self.data_source._determine_fields(weight_field)[0]
+        else:
+            self.standard_deviation = None
         self.weight_field = weight_field
         self.field_units = {}
         ParallelAnalysisInterface.__init__(self, comm=data_source.comm)
 
+    @property
+    def variance(self):
+        issue_deprecation_warning("""
+profile.variance incorrectly returns the profile standard deviation and has 
+been deprecated, use profile.standard_deviation instead."""
+        )
+        return self.standard_deviation
+
     def add_fields(self, fields):
         """Add fields to profile
 
@@ -153,13 +167,13 @@ class ProfileND(ParallelAnalysisInterface):
 
         all_val = np.zeros_like(temp_storage.values)
         all_mean = np.zeros_like(temp_storage.mvalues)
-        all_var = np.zeros_like(temp_storage.qvalues)
+        all_std = np.zeros_like(temp_storage.qvalues)
         all_weight = np.zeros_like(temp_storage.weight_values)
         all_used = np.zeros_like(temp_storage.used, dtype="bool")
 
-        # Combine the weighted mean and variance from each processor.
-        # For two samples with total weight, mean, and variance 
-        # given by w, m, and s, their combined mean and variance are:
+        # Combine the weighted mean and standard deviation from each processor.
+        # For two samples with total weight, mean, and standard deviation 
+        # given by w, m, and s, their combined mean and standard deviation are:
         # m12 = (m1 * w1 + m2 * w2) / (w1 + w2)
         # s12 = (m1 * (s1**2 + (m1 - m12)**2) + 
         #        m2 * (s2**2 + (m2 - m12)**2)) / (w1 + w2)
@@ -180,8 +194,8 @@ class ProfileND(ParallelAnalysisInterface):
                    all_store[p].weight_values)[all_store[p].used] / \
                    all_weight[all_store[p].used]
 
-                all_var[..., i][all_store[p].used] = \
-                  (old_weight * (all_var[..., i] +
+                all_std[..., i][all_store[p].used] = \
+                  (old_weight * (all_std[..., i] +
                                  (old_mean[..., i] - all_mean[..., i])**2) +
                    all_store[p].weight_values *
                    (all_store[p].qvalues[..., i] + 
@@ -189,7 +203,7 @@ class ProfileND(ParallelAnalysisInterface):
                      all_mean[..., i])**2))[all_store[p].used] / \
                     all_weight[all_store[p].used]
 
-        all_var = np.sqrt(all_var)
+        all_std = np.sqrt(all_std)
         del all_store
         self.used = all_used
         blank = ~all_used
@@ -206,10 +220,10 @@ class ProfileND(ParallelAnalysisInterface):
                 self.field_data[field] = \
                   array_like_field(self.data_source, 
                                    all_mean[...,i], field)
-                self.variance[field] = \
+                self.standard_deviation[field] = \
                   array_like_field(self.data_source,
-                                   all_var[...,i], field)
-                self.variance[field][blank] = 0.0
+                                   all_std[...,i], field)
+                self.standard_deviation[field][blank] = 0.0
             self.field_data[field][blank] = 0.0
             self.field_units[field] = self.field_data[field].units
             if isinstance(field, tuple):
@@ -223,47 +237,66 @@ class ProfileND(ParallelAnalysisInterface):
     def _filter(self, bin_fields):
         # cut_points is set to be everything initially, but
         # we also want to apply a filtering based on min/max
-        filter = np.ones(bin_fields[0].shape, dtype='bool')
+        pfilter = np.ones(bin_fields[0].shape, dtype='bool')
         for (mi, ma), data in zip(self.bounds, bin_fields):
-            filter &= (data > mi)
-            filter &= (data < ma)
-        return filter, [data[filter] for data in bin_fields]
+            pfilter &= (data > mi)
+            pfilter &= (data < ma)
+        return pfilter, [data[pfilter] for data in bin_fields]
 
     def _get_data(self, chunk, fields):
         # We are using chunks now, which will manage the field parameters and
         # the like.
         bin_fields = [chunk[bf] for bf in self.bin_fields]
+        for i in range(1, len(bin_fields)):
+            if bin_fields[0].shape != bin_fields[i].shape:
+                    raise YTProfileDataShape(
+                        self.bin_fields[0], bin_fields[0].shape,
+                        self.bin_fields[i], bin_fields[i].shape)
         # We want to make sure that our fields are within the bounds of the
         # binning
-        filter, bin_fields = self._filter(bin_fields)
-        if not np.any(filter): return None
+        pfilter, bin_fields = self._filter(bin_fields)
+        if not np.any(pfilter): return None
         arr = np.zeros((bin_fields[0].size, len(fields)), dtype="float64")
         for i, field in enumerate(fields):
+            if pfilter.shape != chunk[field].shape:
+                raise YTProfileDataShape(
+                    self.bin_fields[0], bin_fields[0].shape,
+                    field, chunk[field].shape)
             units = chunk.ds.field_info[field].output_units
-            arr[:,i] = chunk[field][filter].in_units(units)
+            arr[:,i] = chunk[field][pfilter].in_units(units)
         if self.weight_field is not None:
+            if pfilter.shape != chunk[self.weight_field].shape:
+                raise YTProfileDataShape(
+                    self.bin_fields[0], bin_fields[0].shape,
+                    self.weight_field, chunk[self.weight_field].shape)
             units = chunk.ds.field_info[self.weight_field].output_units
             weight_data = chunk[self.weight_field].in_units(units)
         else:
-            weight_data = np.ones(filter.size, dtype="float64")
-        weight_data = weight_data[filter]
+            weight_data = np.ones(pfilter.shape, dtype="float64")
+        weight_data = weight_data[pfilter]
         # So that we can pass these into
         return arr, weight_data, bin_fields
 
     def __getitem__(self, field):
-        fname = self.field_map.get(field, None)
-        if fname is None:
+        if field in self.field_data:
+            fname = field
+        else:
+            # deal with string vs tuple field names and attempt to guess which field
+            # we are supposed to be talking about
+            fname = self.field_map.get(field, None)
             if isinstance(field, tuple):
                 fname = self.field_map.get(field[1], None)
+                if fname != field:
+                    raise KeyError("Asked for field '{}' but only have data for "
+                                   "field '{}'".format(field, fname))
             elif isinstance(field, DerivedField):
                 fname = self.field_map.get(field.name[1], None)
-        if fname is None:
-            raise KeyError(field)
+            if fname is None:
+                raise KeyError(field)
+        if getattr(self, 'fractional', False):
+            return self.field_data[fname]
         else:
-            if getattr(self, 'fractional', False):
-                return self.field_data[fname]
-            else:
-                return self.field_data[fname].in_units(self.field_units[fname])
+            return self.field_data[fname].in_units(self.field_units[fname])
 
     def items(self):
         return [(k,self[k]) for k in self.field_data.keys()]
@@ -335,11 +368,18 @@ class ProfileND(ParallelAnalysisInterface):
         extra_attrs = {"data_type": "yt_profile",
                        "profile_dimensions": self.size,
                        "weight_field": self.weight_field,
-                       "fractional": self.fractional}
+                       "fractional": self.fractional,
+                       "accumulation": self.accumulation}
         data = {}
         data.update(self.field_data)
         data["weight"] = self.weight
         data["used"] = self.used.astype("float64")
+        std = "standard_deviation"
+        if self.weight_field is not None:
+            std_data = getattr(self, std)
+            data.update(dict(
+                ((std, field[1]), std_data[field])
+                for field in self.field_data))
 
         dimensionality = 0
         bin_data = []
@@ -361,7 +401,10 @@ class ProfileND(ParallelAnalysisInterface):
             data[getattr(self, "%s_field" % ax)] = bin_fields[i]
 
         extra_attrs["dimensionality"] = dimensionality
-        ftypes = dict([(field, "data") for field in data])
+        ftypes = dict([(field, "data") for field in data if field[0] != std])
+        if self.weight_field is not None:
+            ftypes.update(dict(((std, field[1]), std)
+                               for field in self.field_data))
         save_as_dataset(self.ds, filename, data, field_types=ftypes,
                         extra_attrs=extra_attrs)
 
@@ -374,6 +417,7 @@ class ProfileNDFromDataset(ProfileND):
     def __init__(self, ds):
         ProfileND.__init__(self, ds.data, ds.parameters["weight_field"])
         self.fractional = ds.parameters["fractional"]
+        self.accumulation = ds.parameters["accumulation"]
         exclude_fields = ["used", "weight"]
         for ax in "xyz"[:ds.dimensionality]:
             setattr(self, ax, ds.data[ax])
@@ -387,12 +431,16 @@ class ProfileNDFromDataset(ProfileND):
         self.weight = ds.data["weight"]
         self.used = ds.data["used"].d.astype(bool)
         profile_fields = [f for f in ds.field_list
-                          if f[1] not in exclude_fields]
+                          if f[1] not in exclude_fields and
+                             f[0] != "standard_deviation"]
         for field in profile_fields:
             self.field_map[field[1]] = field
             self.field_data[field] = ds.data[field]
             self.field_info[field] = ds.field_info[field]
             self.field_units[field] = ds.data[field].units
+            if ("standard_deviation", field[1]) in ds.field_list:
+                self.standard_deviation[field] = \
+                  ds.data["standard_deviation", field[1]]
 
 class Profile1D(ProfileND):
     """An object that represents a 1D profile.
@@ -417,10 +465,12 @@ class Profile1D(ProfileND):
         spaced in linear (False) or log (True) space.
     weight_field : string field name
         The field to weight the profiled fields by.
+    override_bins_x : array
+        Array to set as xbins and ignore other parameters if set
 
     """
     def __init__(self, data_source, x_field, x_n, x_min, x_max, x_log,
-                 weight_field = None):
+                 weight_field = None, override_bins_x=None):
         super(Profile1D, self).__init__(data_source, weight_field)
         self.x_field = data_source._determine_fields(x_field)[0]
         self.field_info[self.x_field] = \
@@ -431,6 +481,11 @@ class Profile1D(ProfileND):
         self.x_bins = array_like_field(data_source,
                                        self._get_bins(x_min, x_max, x_n, x_log),
                                        self.x_field)
+
+        if override_bins_x is not None:
+            self.x_bins = array_like_field(data_source, override_bins_x,
+                                           self.x_field)
+
         self.size = (self.x_bins.size - 1,)
         self.bin_fields = (self.x_field,)
         self.x = 0.5*(self.x_bins[1:]+self.x_bins[:-1])
@@ -463,6 +518,14 @@ class Profile1D(ProfileND):
     def bounds(self):
         return ((self.x_bins[0], self.x_bins[-1]),)
 
+    def plot(self):
+        r"""
+        This returns a :class:~yt.visualization.profile_plotter.ProfilePlot
+        with the fields that have been added to this object.
+        """
+        from yt.visualization.profile_plotter import ProfilePlot
+        return ProfilePlot.from_profiles(self)
+
 class Profile1DFromDataset(ProfileNDFromDataset, Profile1D):
     """
     A 1D profile object loaded from a ytdata dataset.
@@ -507,12 +570,17 @@ class Profile2D(ProfileND):
         spaced in linear (False) or log (True) space.
     weight_field : string field name
         The field to weight the profiled fields by.
+    override_bins_x : array
+        Array to set as xbins and ignore other parameters if set
+    override_bins_y : array
+        Array to set as ybins and ignore other parameters if set
 
     """
     def __init__(self, data_source,
                  x_field, x_n, x_min, x_max, x_log,
                  y_field, y_n, y_min, y_max, y_log,
-                 weight_field = None):
+                 weight_field = None,
+                 override_bins_x = None, override_bins_y = None):
         super(Profile2D, self).__init__(data_source, weight_field)
         # X
         self.x_field = data_source._determine_fields(x_field)[0]
@@ -524,6 +592,11 @@ class Profile2D(ProfileND):
         self.x_bins = array_like_field(data_source,
                                        self._get_bins(x_min, x_max, x_n, x_log),
                                        self.x_field)
+        if override_bins_x is not None:
+            self.x_bins = array_like_field(data_source, override_bins_x,
+                                           self.x_field)
+
+
         # Y
         self.y_field = data_source._determine_fields(y_field)[0]
         self.y_log = y_log
@@ -534,6 +607,9 @@ class Profile2D(ProfileND):
         self.y_bins = array_like_field(data_source,
                                        self._get_bins(y_min, y_max, y_n, y_log),
                                        self.y_field)
+        if override_bins_y is not None:
+            self.y_bins = array_like_field(data_source, override_bins_y,
+                                           self.y_field)
 
         self.size = (self.x_bins.size - 1, self.y_bins.size - 1)
 
@@ -582,6 +658,14 @@ class Profile2D(ProfileND):
         return ((self.x_bins[0], self.x_bins[-1]),
                 (self.y_bins[0], self.y_bins[-1]))
 
+    def plot(self):
+        r"""
+        This returns a :class:~yt.visualization.profile_plotter.PhasePlot with
+        the fields that have been added to this object.
+        """
+        from yt.visualization.profile_plotter import PhasePlot
+        return PhasePlot.from_profile(self)
+
 class Profile2DFromDataset(ProfileNDFromDataset, Profile2D):
     """
     A 2D profile object loaded from a ytdata dataset.
@@ -634,33 +718,31 @@ class ParticleProfile(Profile2D):
     fractional = False
 
     def __init__(self, data_source,
-                 x_field, x_n, x_min, x_max,
-                 y_field, y_n, y_min, y_max,
+                 x_field, x_n, x_min, x_max, x_log,
+                 y_field, y_n, y_min, y_max, y_log,
                  weight_field=None, deposition="ngp"):
 
         x_field = data_source._determine_fields(x_field)[0]
         y_field = data_source._determine_fields(y_field)[0]
 
+        if deposition not in ['ngp', 'cic']:
+            raise NotImplementedError(deposition)
+        elif (x_log or y_log) and deposition != 'ngp':
+            mylog.warning('cic deposition is only supported for linear axis '
+                          'scales, falling back to ngp deposition')
+            deposition = 'ngp'
+
+        self.deposition = deposition
+
         # set the log parameters to False (since that doesn't make much sense
         # for deposited data) and also turn off the weight field.
         super(ParticleProfile, self).__init__(data_source,
                                               x_field,
-                                              x_n, x_min, x_max, False,
+                                              x_n, x_min, x_max, x_log,
                                               y_field,
-                                              y_n, y_min, y_max, False,
+                                              y_n, y_min, y_max, y_log,
                                               weight_field=weight_field)
 
-        self.LeftEdge = [self.x_bins[0], self.y_bins[0]]
-        self.dx = (self.x_bins[-1] - self.x_bins[0]) / x_n
-        self.dy = (self.y_bins[-1] - self.y_bins[0]) / y_n
-        self.CellSize = [self.dx, self.dy]
-        self.CellVolume = np.product(self.CellSize)
-        self.GridDimensions = np.array([x_n, y_n], dtype=np.int32)
-        self.known_styles = ["ngp", "cic"]
-        if deposition not in self.known_styles:
-            raise NotImplementedError(deposition)
-        self.deposition = deposition
-
     # Either stick the particle field in the nearest bin,
     # or spread it out using the 2D CIC deposition function
     def _bin_chunk(self, chunk, fields, storage):
@@ -669,42 +751,31 @@ class ParticleProfile(Profile2D):
         fdata, wdata, (bf_x, bf_y) = rv
         # make sure everything has the same units before deposition.
         # the units will be scaled to the correct values later.
-        LE = np.array([self.LeftEdge[0].in_units(bf_x.units),
-                       self.LeftEdge[1].in_units(bf_y.units)])
-        cell_size = np.array([self.CellSize[0].in_units(bf_x.units),
-                              self.CellSize[1].in_units(bf_y.units)])
+
+        if self.deposition == "ngp":
+            func = NGPDeposit_2
+        elif self.deposition == "cic":
+            func = CICDeposit_2
+
         for fi, field in enumerate(fields):
-            Np = fdata[:, fi].size
-
-            if self.deposition == "ngp":
-                func = NGPDeposit_2
-            elif self.deposition == 'cic':
-                func = CICDeposit_2
-
             if self.weight_field is None:
                 deposit_vals = fdata[:, fi]
             else:
                 deposit_vals = wdata*fdata[:, fi]
 
-            func(bf_x, bf_y, deposit_vals, Np,
-                 storage.values[:, :, fi],
-                 LE,
-                 self.GridDimensions,
-                 cell_size)
+            func(bf_x, bf_y, deposit_vals, fdata[:, fi].size,
+                 storage.values[:, :, fi], self.x_bins, self.y_bins)
 
-            locs = storage.values[:, :, fi] > 0.0
+            locs = storage.values[:, :, fi] != 0.0
             storage.used[locs] = True
 
             if self.weight_field is not None:
-                func(bf_x, bf_y, wdata, Np,
-                     storage.weight_values,
-                     LE,
-                     self.GridDimensions,
-                     cell_size)
+                func(bf_x, bf_y, wdata, fdata[:, fi].size,
+                     storage.weight_values, self.x_bins, self.y_bins)
             else:
                 storage.weight_values[locs] = 1.0
-            storage.mvalues[locs, fi] = storage.values[locs, fi] \
-                                        / storage.weight_values[locs]
+            storage.mvalues[locs, fi] = \
+                storage.values[locs, fi] / storage.weight_values[locs]
         # We've binned it!
 
 
@@ -757,13 +828,20 @@ class Profile3D(ProfileND):
         spaced in linear (False) or log (True) space.
     weight_field : string field name
         The field to weight the profiled fields by.
+    override_bins_x : array
+        Array to set as xbins and ignore other parameters if set
+    override_bins_y : array
+        Array to set as xbins and ignore other parameters if set
+    override_bins_z : array
+        Array to set as xbins and ignore other parameters if set
 
     """
     def __init__(self, data_source,
                  x_field, x_n, x_min, x_max, x_log,
                  y_field, y_n, y_min, y_max, y_log,
                  z_field, z_n, z_min, z_max, z_log,
-                 weight_field = None):
+                 weight_field = None, override_bins_x=None,
+                 override_bins_y=None,override_bins_z=None):
         super(Profile3D, self).__init__(data_source, weight_field)
         # X
         self.x_field = data_source._determine_fields(x_field)[0]
@@ -775,6 +853,9 @@ class Profile3D(ProfileND):
         self.x_bins = array_like_field(data_source,
                                        self._get_bins(x_min, x_max, x_n, x_log),
                                        self.x_field)
+        if override_bins_x is not None:
+            self.x_bins = array_like_field(data_source, override_bins_x,
+                                           self.x_field)
         # Y
         self.y_field = data_source._determine_fields(y_field)[0]
         self.y_log = y_log
@@ -785,6 +866,9 @@ class Profile3D(ProfileND):
         self.y_bins = array_like_field(data_source,
                                        self._get_bins(y_min, y_max, y_n, y_log),
                                        self.y_field)
+        if override_bins_y is not None:
+            self.y_bins = array_like_field(data_source, override_bins_y,
+                                           self.y_field)
         # Z
         self.z_field = data_source._determine_fields(z_field)[0]
         self.z_log = z_log
@@ -795,6 +879,9 @@ class Profile3D(ProfileND):
         self.z_bins = array_like_field(data_source,
                                        self._get_bins(z_min, z_max, z_n, z_log),
                                        self.z_field)
+        if override_bins_z is not None:
+            self.z_bins = array_like_field(data_source, override_bins_z,
+                                           self.z_field)
 
         self.size = (self.x_bins.size - 1,
                      self.y_bins.size - 1,
@@ -882,7 +969,7 @@ def create_profile(data_source, bin_fields, fields, n_bins=64,
                    extrema=None, logs=None, units=None,
                    weight_field="cell_mass",
                    accumulation=False, fractional=False,
-                   deposition='ngp'):
+                   deposition='ngp', override_bins=None):
     r"""
     Create a 1, 2, or 3D profile object.
 
@@ -915,7 +1002,7 @@ def create_profile(data_source, bin_fields, fields, n_bins=64,
     weight_field : str or tuple field identifier
         The weight field for computing weighted average for the profile
         values.  If None, the profile values are sums of the data in
-        each bin.
+        each bin. Defaults to "cell_mass".
     accumulation : bool or list of bools
         If True, the profile values for a bin n are the cumulative sum of
         all the values from bin 0 to n.  If -True, the sum is reversed so
@@ -923,12 +1010,18 @@ def create_profile(data_source, bin_fields, fields, n_bins=64,
         to n.  If the profile is 2D or 3D, a list of values can be given to
         control the summation in each dimension independently.
         Default: False.
-    fractional : If True the profile values are divided by the sum of all
+    fractional : bool
+        If True the profile values are divided by the sum of all
         the profile data such that the profile represents a probability
         distribution function.
-    deposition : Controls the type of deposition used for ParticlePhasePlots.
+    deposition : strings
+        Controls the type of deposition used for ParticlePhasePlots.
         Valid choices are 'ngp' and 'cic'. Default is 'ngp'. This parameter is
         ignored the if the input fields are not of particle type.
+    override_bins : dict of bins to profile plot with
+        If set, ignores n_bins and extrema settings and uses the
+        supplied bins to profile the field. If a units dict is provided,
+        bins are understood to be in the units specified in the dictionary.
 
 
     Examples
@@ -938,7 +1031,7 @@ def create_profile(data_source, bin_fields, fields, n_bins=64,
     data from profile[<field_name>].
 
     >>> ds = load("DD0046/DD0046")
-    >>> ad = ds.h.all_data()
+    >>> ad = ds.all_data()
     >>> profile = create_profile(ad, [("gas", "density")],
     ...                              [("gas", "temperature"),
     ...                               ("gas", "velocity_x")])
@@ -956,18 +1049,37 @@ def create_profile(data_source, bin_fields, fields, n_bins=64,
         is_pfield.append(wf.particle_type)
         wf = wf.name
 
+    if len(bin_fields) > 1 and isinstance(accumulation, bool):
+        accumulation = [accumulation for _ in range(len(bin_fields))]
+
+    bin_fields = data_source._determine_fields(bin_fields)
+    fields = data_source._determine_fields(fields)
+    units = sanitize_field_tuple_keys(units, data_source)
+    extrema = sanitize_field_tuple_keys(extrema, data_source)
+    logs = sanitize_field_tuple_keys(logs, data_source)
+    override_bins = sanitize_field_tuple_keys(override_bins, data_source)
+
     if any(is_pfield) and not all(is_pfield):
         raise YTIllDefinedProfile(
             bin_fields, data_source._determine_fields(fields), wf, is_pfield)
     elif len(bin_fields) == 1:
         cls = Profile1D
     elif len(bin_fields) == 2 and all(is_pfield):
-        # log bin_fields set to False for Particle Profiles.
-        # doesn't make much sense for CIC deposition.
-        # accumulation and fractional set to False as well.
-        logs = {bin_fields[0]: False, bin_fields[1]: False}
-        accumulation = False
-        fractional = False
+        if deposition == 'cic':
+            if logs is not None:
+                if ((bin_fields[0] in logs and logs[bin_fields[0]]) or
+                    (bin_fields[1] in logs and logs[bin_fields[1]])):
+                    raise RuntimeError(
+                        "CIC deposition is only implemented for linear-scaled "
+                        "axes")
+            else:
+                logs = {bin_fields[0]: False, bin_fields[1]: False}
+            if any(accumulation) or fractional:
+                raise RuntimeError(
+                    'The accumulation and fractional keyword arguments must be '
+                    'False for CIC deposition')
+        elif logs is None:
+            logs = {bin_fields[0]: False, bin_fields[1]: False}
         cls = ParticleProfile
     elif len(bin_fields) == 2:
         cls = Profile2D
@@ -975,11 +1087,6 @@ def create_profile(data_source, bin_fields, fields, n_bins=64,
         cls = Profile3D
     else:
         raise NotImplementedError
-    bin_fields = data_source._determine_fields(bin_fields)
-    fields = data_source._determine_fields(fields)
-    units = sanitize_field_tuple_keys(units, data_source)
-    extrema = sanitize_field_tuple_keys(extrema, data_source)
-    logs = sanitize_field_tuple_keys(logs, data_source)
     if weight_field is not None and cls == ParticleProfile:
         weight_field, = data_source._determine_fields([weight_field])
         if not data_source.ds._get_field_info(weight_field).particle_type:
@@ -1012,13 +1119,41 @@ def create_profile(data_source, bin_fields, fields, n_bins=64,
             try:
                 field_ex = list(extrema[bin_field[-1]])
             except KeyError:
-                field_ex = list(extrema[bin_field])
+                try:
+                    field_ex = list(extrema[bin_field])
+                except KeyError:
+                    raise RuntimeError("Could not find field {0} or {1} in extrema".format(bin_field[-1], bin_field))
+
+            if isinstance(field_ex[0], tuple):
+                field_ex = [data_source.ds.quan(*f) for f in field_ex]
+            if any([exi is None for exi in field_ex]):
+                try:
+                    ds_extrema = data_source.quantities.extrema(bin_field)
+                except AttributeError:
+                    # ytdata profile datasets don't have data_source.quantities
+                    bf_vals = data_source[bin_field]
+                    ds_extrema = data_source.ds.arr(
+                        [bf_vals.min(), bf_vals.max()])
+                for i, exi in enumerate(field_ex):
+                    if exi is None:
+                        field_ex[i] = ds_extrema[i]
+                        # pad extrema by epsilon so cells at bin edges are
+                        # not excluded
+                        field_ex[i] -= (-1)**i*np.spacing(field_ex[i])
             if units is not None and bin_field in units:
-                if isinstance(field_ex[0], tuple):
-                    field_ex = [data_source.ds.quan(*f) for f in field_ex]
-                fe = data_source.ds.arr(field_ex, units[bin_field])
-                fe.convert_to_units(bf_units)
-                field_ex = [fe[0].v, fe[1].v]
+                for i, exi in enumerate(field_ex):
+                    if hasattr(exi, 'units'):
+                        field_ex[i] = exi.to(units[bin_field])
+                    else:
+                        field_ex[i] = data_source.ds.quan(exi, units[bin_field])
+                fe = data_source.ds.arr(field_ex)
+            else:
+                if hasattr(field_ex, 'units'):
+                    fe = field_ex.to(bf_units)
+                else:
+                    fe = data_source.ds.arr(field_ex, bf_units)
+            fe.convert_to_units(bf_units)
+            field_ex = [fe[0].v, fe[1].v]
             if iterable(field_ex[0]):
                 field_ex[0] = data_source.ds.quan(field_ex[0][0], field_ex[0][1])
                 field_ex[0] = field_ex[0].in_units(bf_units)
@@ -1026,18 +1161,48 @@ def create_profile(data_source, bin_fields, fields, n_bins=64,
                 field_ex[1] = data_source.ds.quan(field_ex[1][0], field_ex[1][1])
                 field_ex[1] = field_ex[1].in_units(bf_units)
             ex.append(field_ex)
+
+    if override_bins is not None:
+        o_bins = []
+        for bin_field in bin_fields:
+            bf_units = data_source.ds.field_info[bin_field].output_units
+            try:
+                field_obin = override_bins[bin_field[-1]]
+            except KeyError:
+                field_obin = override_bins[bin_field]
+
+            if field_obin is None:
+                o_bins.append(None)
+                continue
+
+            if isinstance(field_obin, tuple):
+                field_obin = data_source.ds.arr(*field_obin)
+
+            if units is not None and bin_field in units:
+                fe = data_source.ds.arr(field_obin, units[bin_field])
+            else:
+                if hasattr(field_obin, 'units'):
+                    fe = field_obin.to(bf_units)
+                else:
+                    fe = data_source.ds.arr(field_obin, bf_units)
+            fe.convert_to_units(bf_units)
+            field_obin = fe.d
+            o_bins.append(field_obin)
+
+    args = [data_source]
+    for f, n, (mi, ma), l in zip(bin_fields, n_bins, ex, logs):
+        if mi <= 0 and l:
+            raise YTIllDefinedBounds(mi, ma)
+        args += [f, n, mi, ma, l]
+    kwargs = dict(weight_field=weight_field)
     if cls is ParticleProfile:
-        args = [data_source]
-        for f, n, (mi, ma) in zip(bin_fields, n_bins, ex):
-            args += [f, n, mi, ma]
-        obj = cls(*args, weight_field=weight_field, deposition=deposition)
-    else:
-        args = [data_source]
-        for f, n, (mi, ma), l in zip(bin_fields, n_bins, ex, logs):
-            args += [f, n, mi, ma, l]
-        obj = cls(*args, weight_field = weight_field)
-        setattr(obj, "accumulation", accumulation)
-        setattr(obj, "fractional", fractional)
+        kwargs['deposition'] = deposition
+    if override_bins is not None:
+        for o_bin, ax in zip(o_bins, ['x','y','z']):
+            kwargs["override_bins_{0}".format(ax)] = o_bin
+    obj = cls(*args, **kwargs)
+    setattr(obj, "accumulation", accumulation)
+    setattr(obj, "fractional", fractional)
     if fields is not None:
         obj.add_fields([field for field in fields])
     for field in fields:
