@@ -4,6 +4,8 @@ from yt.frontends.stream.data_structures import load_particles
 from yt.testing import fake_random_ds, assert_equal, assert_almost_equal, \
     fake_octree_ds
 
+from yt.units import kpc
+
 def setup():
     from yt.config import ytcfg
     ytcfg["yt","__withintesting"] = "True"
@@ -160,3 +162,39 @@ def test_arbitrary_grid_derived_field():
     galgas = ds.arbitrary_grid([0.4, 0.4, 0.4], [0.99, 0.99, 0.99],
                                dims=[32, 32, 32])
     galgas['tracerf']
+
+def test_arbitrary_grid_edge():
+    # Tests bug fix for issue #2087
+    # Regardless of how left_edge and right_edge are passed, the result should be
+    # a YTArray with a unit registry that matches that of the dataset.
+    dims = [32,32,32]
+    ds = fake_random_ds(dims)
+    # Test when edge is a list, numpy array, YTArray with dataset units, and
+    # YTArray with non-dataset units
+    ledge = [ [0., 0., 0.],
+            np.array([0., 0., 0.]),
+            [0., 0., 0.] * ds.length_unit,
+            [0., 0., 0.] * kpc]
+
+    redge = [ [1., 1., 1.],
+            np.array([1., 1., 1.]),
+            [1., 1., 1.] * ds.length_unit,
+            [1., 1., 1.] * kpc]
+
+    ledge_ans = [ [0., 0., 0.] * ds.length_unit.to('code_length'),
+                np.array([0., 0., 0.]) * ds.length_unit.to('code_length'),
+                [0., 0., 0.] * ds.length_unit,
+                [0., 0., 0.] * kpc]
+
+    redge_ans = [ [1., 1., 1.] * ds.length_unit.to('code_length'),
+                np.array([1., 1., 1.]) * ds.length_unit.to('code_length'),
+                [1., 1., 1.] * ds.length_unit,
+                [1., 1., 1.] * kpc]
+
+    for le, re, le_ans, re_ans in zip(ledge, redge, ledge_ans, redge_ans):
+        ag = ds.arbitrary_grid(left_edge = le, right_edge = re, dims = dims)
+        assert np.array_equal(ag.left_edge, le_ans)
+        assert np.array_equal(ag.right_edge, re_ans)
+        assert ag.left_edge.units.registry == ds.unit_registry
+        assert ag.right_edge.units.registry == ds.unit_registry
+        ag['density']
