@@ -1,21 +1,23 @@
-import yt
 import numpy as np
+import os
+import shutil
+import tempfile
+import unittest
+import yt
 
-from yt.data_objects.profiles import \
-    Profile1D, \
-    Profile2D, \
-    Profile3D, \
+from yt.utilities.exceptions import \
+    YTProfileDataShape
+from yt.data_objects.particle_filters import add_particle_filter
+from yt.data_objects.profiles import Profile1D, Profile2D, Profile3D,\
     create_profile
 from yt.testing import \
-    fake_random_ds, \
     assert_equal, \
-    assert_raises, \
-    assert_rel_equal
-from yt.utilities.exceptions import \
-    YTIllDefinedProfile
-from yt.visualization.profile_plotter import \
-    ProfilePlot, \
-    PhasePlot
+    assert_raises,\
+    assert_rel_equal, \
+    fake_random_ds, \
+    requires_module
+from yt.utilities.exceptions import YTIllDefinedProfile
+from yt.visualization.profile_plotter import ProfilePlot, PhasePlot
 
 _fields = ("density", "temperature", "dinosaurs", "tribbles")
 _units = ("g/cm**3", "K", "dyne", "erg")
@@ -270,3 +272,127 @@ def test_particle_profile_negative_field():
                     'particle_position_z': False},
             weight_field=None, deposition='cic',
             accumulation=True, fractional=True)
+
+def test_profile_zero_weight():
+    def DMparticles(pfilter, data):
+        filter = data[(pfilter.filtered_type, "particle_type")] == 1
+        return filter
+
+    def DM_in_cell_mass(field, data):
+        return data['deposit', 'DM_density']*data['index', 'cell_volume']
+
+    add_particle_filter("DM", function=DMparticles,
+                        filtered_type='io', requires=["particle_type"])
+
+    _fields = ("particle_position_x", "particle_position_y",
+               "particle_position_z", "particle_mass", "particle_velocity_x",
+               "particle_velocity_y", "particle_velocity_z", "particle_type")
+    _units = ('cm', 'cm', 'cm', 'g', 'cm/s', 'cm/s', 'cm/s', 'dimensionless')
+    ds = fake_random_ds(32, particle_fields=_fields,
+                        particle_field_units=_units, particles=16)
+
+    ds.add_particle_filter('DM')
+    ds.add_field(("gas", "DM_cell_mass"), units="g", function=DM_in_cell_mass,
+                 sampling_type='cell')
+
+    sp = ds.sphere(ds.domain_center, (10, 'kpc'))
+
+    profile = yt.create_profile(sp,
+                                [("gas", "density")],
+                                [("gas", "radial_velocity")],
+                                weight_field=("gas", "DM_cell_mass"))
+
+    assert not np.any(np.isnan(profile['gas', 'radial_velocity']))
+
+def test_profile_override_limits():
+    ds = fake_random_ds(64, nprocs = 8, fields = _fields, units = _units)
+
+    sp = ds.sphere(ds.domain_center, (10, 'kpc'))
+    obins = np.linspace(-5,5,10)
+    profile = yt.create_profile(sp,
+                                [ "density"],["temperature"],
+                                override_bins={"density":(obins, "g/cm**3")})
+    assert_equal(ds.arr(obins, "g/cm**3"), profile.x_bins)
+
+    profile = yt.create_profile(sp,
+                                [ "density", "dinosaurs"],["temperature"],
+                                override_bins={"density":(obins, "g/cm**3"),
+                                               "dinosaurs":obins})
+    assert_equal(ds.arr(obins, "g/cm**3"), profile.x_bins)
+    assert_equal(ds.arr(obins, "dyne"), profile.y_bins)
+
+    profile = yt.create_profile(sp,
+                                [ "density", "dinosaurs", "tribbles"],["temperature"],
+                                override_bins={"density":(obins, "g/cm**3"),
+                                               "dinosaurs":obins,
+                                               "tribbles":(obins, "erg")})
+    assert_equal(ds.arr(obins, "g/cm**3"), profile.x_bins)
+    assert_equal(ds.arr(obins, "dyne"), profile.y_bins)
+    assert_equal(ds.arr(obins, "erg"), profile.z_bins)
+
+class TestBadProfiles(unittest.TestCase):
+
+    tmpdir = None
+    curdir = None
+
+    def setUp(self):
+        self.tmpdir = tempfile.mkdtemp()
+        self.curdir = os.getcwd()
+        os.chdir(self.tmpdir)
+
+    def tearDown(self):
+        os.chdir(self.curdir)
+        # clean up
+        shutil.rmtree(self.tmpdir)
+
+    @requires_module('h5py')
+    def test_unequal_data_shape_profile(self):
+        density = np.random.random(128)
+        temperature = np.random.random(128)
+        cell_mass = np.random.random((128, 128))
+
+        my_data = {
+            "density": density,
+            "temperature": temperature,
+            "cell_mass": cell_mass}
+        fake_ds_med = {"current_time": yt.YTQuantity(10, "Myr")}
+        yt.save_as_dataset(fake_ds_med, "mydata.h5", my_data)
+
+        ds = yt.load('mydata.h5')
+
+        assert_raises(
+            YTProfileDataShape,
+            yt.PhasePlot, ds.data, 'temperature', 'density', 'cell_mass')
+
+    @requires_module('h5py')
+    def test_unequal_bin_field_profile(self):
+        density = np.random.random(128)
+        temperature = np.random.random(127)
+        cell_mass = np.random.random((128, 128))
+
+        my_data = {
+            "density": density,
+            "temperature": temperature,
+            "cell_mass": cell_mass}
+        fake_ds_med = {"current_time": yt.YTQuantity(10, "Myr")}
+        yt.save_as_dataset(fake_ds_med, "mydata.h5", my_data)
+
+        ds = yt.load('mydata.h5')
+
+        assert_raises(
+            YTProfileDataShape,
+            yt.PhasePlot, ds.data, 'temperature', 'density', 'cell_mass')
+
+def test_index_field_units():
+    # see #1849
+    ds = fake_random_ds(16, length_unit=2)
+    ad = ds.all_data()
+    icv_units = ad['index', 'cell_volume'].units
+    assert str(icv_units) == 'code_length**3'
+    gcv_units = ad['gas', 'cell_volume'].units
+    assert str(gcv_units) == 'cm**3'
+    prof = ad.profile(['density', 'velocity_x'],
+                      [('gas', 'cell_volume'), ('index', 'cell_volume')],
+                      weight_field=None)
+    assert str(prof['index', 'cell_volume'].units) == 'code_length**3'
+    assert str(prof['gas', 'cell_volume'].units) == 'cm**3'
