@@ -45,14 +45,14 @@ def setup_cosmology_fields(registry, ftype = "gas", slice_info = None):
         return data[ftype, "density"] + \
           data[ftype, "dark_matter_density"]
 
-    registry.add_field((ftype, "matter_density"),
+    registry.add_field((ftype, "matter_density"), sampling_type="cell", 
                        function=_matter_density,
                        units=unit_system["density"])
 
     def _matter_mass(field, data):
         return data[ftype, "matter_density"] * data["index", "cell_volume"]
 
-    registry.add_field((ftype, "matter_mass"),
+    registry.add_field((ftype, "matter_mass"), sampling_type="cell", 
                        function=_matter_mass,
                        units=unit_system["mass"])
 
@@ -65,7 +65,7 @@ def setup_cosmology_fields(registry, ftype = "gas", slice_info = None):
         return data[ftype, "matter_density"] / \
           co.critical_density(data.ds.current_redshift)
 
-    registry.add_field((ftype, "overdensity"),
+    registry.add_field((ftype, "overdensity"), sampling_type="cell", 
                        function=_overdensity,
                        units="")
 
@@ -83,7 +83,7 @@ def setup_cosmology_fields(registry, ftype = "gas", slice_info = None):
         return data[ftype, "density"] / omega_baryon / co.critical_density(0.0) / \
           (1.0 + data.ds.current_redshift)**3
 
-    registry.add_field((ftype, "baryon_overdensity"),
+    registry.add_field((ftype, "baryon_overdensity"), sampling_type="cell", 
                        function=_baryon_overdensity,
                        units="",
                        validators=[ValidateParameter("omega_baryon")])
@@ -100,16 +100,20 @@ def setup_cosmology_fields(registry, ftype = "gas", slice_info = None):
           co.critical_density(0.0) / \
           (1.0 + data.ds.current_redshift)**3
 
-    registry.add_field((ftype, "matter_overdensity"),
+    registry.add_field((ftype, "matter_overdensity"), sampling_type="cell", 
                        function=_matter_overdensity,
                        units="")
 
     # r / r_vir
     def _virial_radius_fraction(field, data):
         virial_radius = data.get_field_parameter("virial_radius")
-        return data["radius"] / virial_radius
+        if virial_radius == 0.0:
+            ret = 0.0
+        else:
+            ret = data["radius"] / virial_radius
+        return ret
 
-    registry.add_field(("index", "virial_radius_fraction"),
+    registry.add_field(("index", "virial_radius_fraction"), sampling_type="cell", 
                        function=_virial_radius_fraction,
                        validators=[ValidateParameter("virial_radius")],
                        units="")
@@ -137,7 +141,7 @@ def setup_cosmology_fields(registry, ftype = "gas", slice_info = None):
         return (1.5 * (co.hubble_constant / speed_of_light_cgs)**2 * (dl * dls / ds) * \
           data[ftype, "matter_overdensity"]).in_units("1/cm")
 
-    registry.add_field((ftype, "weak_lensing_convergence"),
+    registry.add_field((ftype, "weak_lensing_convergence"), sampling_type="cell", 
                        function=_weak_lensing_convergence,
                        units=unit_system["length"]**-1,
         validators=[ValidateParameter("observer_redshift"),
