@@ -33,8 +33,8 @@ gc = "GaussianCloud/data.0077.3d.hdf5"
 @requires_ds(gc)
 def test_gc():
     ds = data_dir_load(gc)
-    yield assert_equal, str(ds), "data.0077.3d.hdf5"
-    for test in small_patch_amr(gc, _fields):
+    assert_equal(str(ds), "data.0077.3d.hdf5")
+    for test in small_patch_amr(ds, _fields):
         test_gc.__name__ = test.description
         yield test
 
@@ -42,8 +42,8 @@ tb = "TurbBoxLowRes/data.0005.3d.hdf5"
 @requires_ds(tb)
 def test_tb():
     ds = data_dir_load(tb)
-    yield assert_equal, str(ds), "data.0005.3d.hdf5"
-    for test in small_patch_amr(tb, _fields):
+    assert_equal(str(ds), "data.0005.3d.hdf5")
+    for test in small_patch_amr(ds, _fields):
         test_tb.__name__ = test.description
         yield test
 
@@ -51,8 +51,8 @@ iso = "IsothermalSphere/data.0000.3d.hdf5"
 @requires_ds(iso)
 def test_iso():
     ds = data_dir_load(iso)
-    yield assert_equal, str(ds), "data.0000.3d.hdf5"
-    for test in small_patch_amr(iso, _fields):
+    assert_equal(str(ds), "data.0000.3d.hdf5")
+    for test in small_patch_amr(ds, _fields):
         test_iso.__name__ = test.description
         yield test
 
@@ -61,8 +61,8 @@ zp = "ZeldovichPancake/plt32.2d.hdf5"
 @requires_ds(zp)
 def test_zp():
     ds = data_dir_load(zp)
-    yield assert_equal, str(ds), "plt32.2d.hdf5"
-    for test in small_patch_amr(zp, _zp_fields, input_center="c",
+    assert_equal(str(ds), "plt32.2d.hdf5")
+    for test in small_patch_amr(ds, _zp_fields, input_center="c",
                                 input_weight="rhs"):
         test_zp.__name__ = test.description
         yield test
@@ -71,8 +71,8 @@ kho = "KelvinHelmholtz/data.0004.hdf5"
 @requires_ds(kho)
 def test_kho():
     ds = data_dir_load(kho)
-    yield assert_equal, str(ds), "data.0004.hdf5"
-    for test in small_patch_amr(kho, _fields):
+    assert_equal(str(ds), "data.0004.hdf5")
+    for test in small_patch_amr(ds, _fields):
         test_kho.__name__ = test.description
         yield test
 
@@ -92,15 +92,12 @@ def test_PlutoDataset():
 
 @requires_file(zp)
 def test_units_override_zp():
-    for test in units_override_check(zp):
-        yield test
+    units_override_check(zp)
 
 @requires_file(gc)
 def test_units_override_gc():
-    for test in units_override_check(gc):
-        yield test
+    units_override_check(gc)
 
 @requires_file(kho)
 def test_units_override_kho():
-    for test in units_override_check(kho):
-        yield test
+    units_override_check(kho)
