@@ -1,5 +1,5 @@
 """
-Polar fields
+Definitions for polar coordinate systems
 
 
 
@@ -14,20 +14,12 @@ Polar fields
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
-import numpy as np
-from yt.units.yt_array import YTArray
-from .coordinate_handler import \
-    CoordinateHandler, \
-    _unknown_coord, \
-    cylindrical_to_cartesian, \
-    _get_coord_fields
 from .cylindrical_coordinates import CylindricalCoordinateHandler
-import yt.visualization._MPL as _MPL
-from yt.utilities.lib.pixelization_routines import \
-    pixelize_cylinder
+
 
 class PolarCoordinateHandler(CylindricalCoordinateHandler):
+    name = "polar"
 
-  def __init__(self, ds, ordering = ('r', 'theta', 'z')):
+    def __init__(self, ds, ordering = ('r', 'theta', 'z')):
         super(PolarCoordinateHandler, self).__init__(ds, ordering)
         # No need to set labels here
