@@ -14,31 +14,23 @@ from __future__ import print_function
 # The full license is in the file COPYING.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
-import h5py
+from yt.utilities.on_demand_imports import _h5py as h5py
 import numpy as np
-import string, re, gc, time
-from yt.extern.six.moves import cPickle
-from yt.extern.six.moves import zip as izip
 import weakref
 
-from itertools import chain
+from collections import defaultdict
 
-from yt.funcs import *
-from yt.utilities.logger import ytLogger as mylog
 from yt.arraytypes import blankRecordArray
 from yt.config import ytcfg
-from yt.fields.field_info_container import NullFunc
+from yt.funcs import \
+    ensure_list, ensure_numpy_array
 from yt.geometry.geometry_handler import \
     Index, YTDataChunk, ChunkDataCache
 from yt.utilities.definitions import MAXLEVEL
-from yt.utilities.physical_constants import sec_per_year
-from yt.utilities.io_handler import io_registry
-from yt.utilities.parallel_tools.parallel_analysis_interface import \
-    ParallelAnalysisInterface
+from yt.utilities.logger import ytLogger as mylog
 from .grid_container import \
     GridTree, MatchPointsToGrids
 
-from yt.data_objects.data_containers import data_object_registry
 
 class GridIndex(Index):
     """The index class for patch and block AMR datasets. """
@@ -127,13 +119,16 @@ class GridIndex(Index):
         """
         return self.select_grids(self.grid_levels.max())[0].dds[:].min()
 
+    def _get_particle_type_counts(self):
+        return {self.ds.particle_types_raw[0]: self.grid_particle_count.sum()}
+
     def _initialize_level_stats(self):
         # Now some statistics:
         #   0 = number of grids
         #   1 = number of cells
         #   2 = blank
         desc = {'names': ['numgrids','numcells','level'],
-                'formats':['Int64']*3}
+                'formats':['int64']*3}
         self.level_stats = blankRecordArray(desc, MAXLEVEL)
         self.level_stats['level'] = [i for i in range(MAXLEVEL)]
         self.level_stats['numgrids'] = [0 for i in range(MAXLEVEL)]
@@ -201,7 +196,6 @@ class GridIndex(Index):
              self.ds.current_time.in_units("s"),
              self.ds.current_time.in_units("yr")))
         print("\nSmallest Cell:")
-        u=[]
         for item in ("Mpc", "pc", "AU", "cm"):
             print("\tWidth: %0.3e %s" % (dx.in_units(item), item))
 
@@ -288,10 +282,6 @@ class GridIndex(Index):
 
     def _identify_base_chunk(self, dobj):
         fast_index = None
-        def _gsort(g):
-            if g.filename is None:
-                return g.id
-            return g.filename
         if dobj._type_name == "grid":
             dobj._chunk_info = np.empty(1, dtype='object')
             dobj._chunk_info[0] = weakref.proxy(dobj)
@@ -299,6 +289,10 @@ class GridIndex(Index):
             gi = dobj.selector.select_grids(self.grid_left_edge,
                                             self.grid_right_edge,
                                             self.grid_levels)
+            if any([g.filename is not None for g in self.grids[gi]]):
+                _gsort = _grid_sort_mixed
+            else:
+                _gsort = _grid_sort_id
             grids = list(sorted(self.grids[gi], key = _gsort))
             dobj._chunk_info = np.empty(len(grids), dtype='object')
             for i, g in enumerate(grids):
@@ -330,9 +324,9 @@ class GridIndex(Index):
     def _chunk_spatial(self, dobj, ngz, sort = None, preload_fields = None):
         gobjs = getattr(dobj._current_chunk, "objs", dobj._chunk_info)
         if sort in ("+level", "level"):
-            giter = sorted(gobjs, key = g.Level)
+            giter = sorted(gobjs, key=lambda g: g.Level)
         elif sort == "-level":
-            giter = sorted(gobjs, key = -g.Level)
+            giter = sorted(gobjs, key=lambda g: -g.Level)
         elif sort is None:
             giter = gobjs
         if preload_fields is None: preload_fields = []
@@ -362,7 +356,8 @@ class GridIndex(Index):
         gobjs = getattr(dobj._current_chunk, "objs", dobj._chunk_info)
         fast_index = dobj._current_chunk._fast_index
         for g in gobjs:
-            gfiles[g.filename].append(g)
+            # Force to be a string because sometimes g.filename is None.
+            gfiles[str(g.filename)].append(g)
         # We can apply a heuristic here to make sure we aren't loading too
         # many grids all at once.
         if chunk_sizing == "auto":
@@ -392,3 +387,12 @@ class GridIndex(Index):
                 with self.io.preload(dc, preload_fields, 
                             4.0 * size):
                     yield dc
+
+
+def _grid_sort_id(g):
+    return g.id
+
+def _grid_sort_mixed(g):
+    if g.filename is None:
+        return str(g.id)
+    return g.filename
