@@ -30,6 +30,9 @@ base_dimensions = [mass, length, time, temperature, angle, current_mks,
 #
 
 rate = 1 / time
+frequency = rate
+
+solid_angle = angle * angle
 
 velocity     = length / time
 acceleration = length / time**2
@@ -49,6 +52,11 @@ flux     = power / area
 specific_flux = flux / rate
 number_density = 1/(length*length*length)
 density = mass * number_density
+angular_momentum = mass*length*velocity
+specific_angular_momentum = angular_momentum / mass
+specific_energy = energy / mass
+count_flux = 1 / (area*time)
+count_intensity = count_flux / solid_angle
 
 # Gaussian electromagnetic units
 charge_cgs  = (energy * length)**Rational(1, 2)  # proper 1/2 power
@@ -73,8 +81,6 @@ electric_potential = electric_potential_cgs
 resistance = resistance_cgs
 current = current_cgs
 
-solid_angle = angle * angle
-
 derived_dimensions = [rate, velocity, acceleration, jerk, snap, crackle, pop, 
                       momentum, force, energy, power, charge_cgs, electric_field_cgs,
                       magnetic_field_cgs, solid_angle, flux, specific_flux, volume,
