@@ -9,9 +9,9 @@ def test_element_accuracy():
         # If num == -1, then we are in one of the things like Deuterium or El
         # that are not elements by themselves.
         if num == -1: e0 = e1
-        yield assert_equal, id(e0), id(e1)
-        yield assert_equal, id(e0), id(e2)
-        yield assert_equal, e0.num, num
-        yield assert_equal, e0.weight, w
-        yield assert_equal, e0.name, name
-        yield assert_equal, e0.symbol, sym
+        assert_equal(id(e0), id(e1))
+        assert_equal(id(e0), id(e2))
+        assert_equal(e0.num, num)
+        assert_equal(e0.weight, w)
+        assert_equal(e0.name, name)
+        assert_equal(e0.symbol, sym)
